==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_pt.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=pt
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'aucun_message_forum' => 'Sem mensagens de fórum',

	// B
	'bouton_radio_articles_futurs' => 'aos futuros artigos unicamente (não há acção sobre a base de dados) ',
	'bouton_radio_articles_tous' => 'a todos os artigos sem excepção',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'a todos os artigos, excepto aqueles cujo fórum está desactivado',
	'bouton_radio_enregistrement_obligatoire' => 'Registo obrigatório (os
utilizadores devem ter uma assinatura ao fornecer o seu endereço e-mail antes de
 poderem enviar contribuições).',
	'bouton_radio_moderation_priori' => 'Pré-moderação (as contribuições aparecem publicamente só depois da validação pelos administradores). ',
	'bouton_radio_modere_abonnement' => 'requer assinatura',
	'bouton_radio_modere_posteriori' => 'moderado depois da publicação',
	'bouton_radio_modere_priori' => 'moderado antes da publicação',
	'bouton_radio_publication_immediate' => 'Publicação imediata das mensagens
 (as contribuições afixam-se logo que são enviadas, os administradores podem suprimi-las depois).',

	// D
	'documents_interdits_forum' => 'Documentos proibidos no fórum',

	// E
	'erreur_enregistrement_message' => 'A sua mensagem não pôde ser guardada devido a um problema técnico',
	'extensions_autorisees' => 'Extensões permitidas:',
	'extensions_autorisees_toutes' => 'todas',

	// F
	'form_pet_message_commentaire' => 'Alguma mensagem ou comentário ?',
	'forum' => 'Fórum',
	'forum_acces_refuse' => 'Já não tem acesso a estes fóruns.',
	'forum_attention_dix_caracteres' => '<b>Atenção !</b> a sua mensagem deve conter pelo menos dez carácteres.',
	'forum_attention_message_non_poste' => 'Atenção! Não publicou a sua mensagem!',
	'forum_attention_nb_caracteres_mini' => '<b>Atenção !</b> A sua mensagem deve conter pelo menos @min@ caracteres.',
	'forum_attention_trois_caracteres' => '<b>Atenção !</b> o seu título deve conter pelo menos três carácteres.',
	'forum_attention_trop_caracteres' => '<b>Atenção !</b> A sua mensagem é demasiado longa (@compte@ caracteres) : para poder ser guardada não pode conter mais de @max@ caracteres.',
	'forum_avez_selectionne' => 'Seleccionou :',
	'forum_cliquer_retour' => 'Clique <a href=\'@retour_forum@\'>ici</a> para continuar.',
	'forum_envoyer' => 'Enviar',
	'forum_forum' => 'fórum',
	'forum_info_modere' => 'Este fórum é moderado antes da publicação : a sua contribuição só aparecerá depois de ser validada por um administrador do sítio.',
	'forum_lien_hyper' => '<b>Link hipertexto</b> (opcional)',
	'forum_message' => 'A sua mensagem',
	'forum_message_definitif' => 'Mensagem definitiva: enviar para o sítio',
	'forum_message_trop_long' => 'A sua mensagem é demasiado longa. O tamanho máximo é 20000 carácteres.',
	'forum_ne_repondez_pas' => 'Não responda e este e-mail. Por favor use o fórum, com o endereço seguinte:',
	'forum_page_url' => '(Se a sua mensagem se refere a um artigo publicado na Web, ou a uma página que fornece mais informações, por favor indique a seguir o título da página e o seu endereço URL.)',
	'forum_permalink' => 'Ligação permanente ao comentário',
	'forum_poste_par' => 'Mensagem publicada @parauteur@ a seguir ao seu artigo "@titre@"',
	'forum_poste_par_court' => 'Mensagem publicada @parauteur@.',
	'forum_poste_par_generique' => 'Mensagem publicada @parauteur@ (@objet@ « @titre@ »).',
	'forum_qui_etes_vous' => '<b>Quem é você?</b> (opcional)',
	'forum_saisie_texte_info' => 'este formulário aceita atalhos SPIP <code>[-&gt;url] {{bold}} {itálico} &lt;quote&gt; &lt;code&gt;</code> e o código HTML <code>&lt;q&gt; &lt;del&gt; &lt;ins&gt;</code>. Para criar parágrafos, deixe linhas vazias.',
	'forum_texte' => 'Texto da sua mensagem:',
	'forum_titre' => 'Título:',
	'forum_url' => 'O seu sítio (URL):',
	'forum_valider' => 'Validar a sua escolha',
	'forum_voir_avant' => 'Pré-visualizar',
	'forum_votre_email' => 'O seu endereço e-mail:',
	'forum_votre_nom' => 'O seu nome (pseudónimo):',
	'forum_vous_enregistrer' => 'Para participar
 nesse fórum, deve estar previamente registado. Por favor
  indique a seguir o identificador pessoal que lhe foi
 fornecido. Se não está registado, deve  ',
	'forum_vous_inscrire' => 'inscrever-se.',

	// I
	'icone_bruler_message' => 'Assinalar como Spam',
	'icone_bruler_messages' => 'Assinalar como Spam',
	'icone_legitimer_message' => 'Assinalar como legal',
	'icone_poster_message' => 'Enviar uma mensagem ',
	'icone_suivi_forum' => 'Seguimento do fórum público : @nb_forums@ contribuição(ões)',
	'icone_suivi_forums' => 'Seguir/gerir os fóruns',
	'icone_supprimer_message' => 'Eliminar esta mensagem',
	'icone_supprimer_messages' => 'eliminar estas mensagens',
	'icone_valider_message' => 'Validar esta mensagem',
	'icone_valider_messages' => 'Validar estas mensagens',
	'icone_valider_repondre_message' => 'Validar & Responder a esta mensagem',
	'info_1_message_forum' => '1 mensagem de fórum',
	'info_activer_forum_public' => '<i>Para activar os fóruns públicos, por favor escolha o seu modo
  de moderação por defeito </i>',
	'info_appliquer_choix_moderation' => 'Aplicar esta escolha de moderação :',
	'info_config_forums_prive' => 'Na área privada do sítio pode activar vários tipos de fóruns:',
	'info_config_forums_prive_admin' => 'Um fórum reservado aos administradores do sítio :',
	'info_config_forums_prive_global' => 'Um fórum global, aberto a todos os autores:',
	'info_config_forums_prive_objets' => 'Um fórum sobre cada artigo, notícia, referência, etc.:',
	'info_desactiver_forum_public' => 'Desactivar a utilização dos fóruns
 públicos. Os fóruns públicos poderão ser autorizados caso a caso
 nos artigos ; serão proibidos nas rubricas, notícias, etc.',
	'info_envoi_forum' => 'Envio dos fóruns aos autores dos artigos',
	'info_fonctionnement_forum' => 'Funcionamento do fórum :',
	'info_forcer_previsualisation_court' => 'Forçar pré-visualização',
	'info_forcer_previsualisation_long' => 'Forçar pré-visualização antes de enviar mensagem',
	'info_forums_liees_mot' => 'Mensagens de fórum ligadas a esta palavra-chave',
	'info_gauche_suivi_forum_2' => 'A página <i>gestão dos fóruns </i> é um instrumento de gestão do seu sítio (e não um espaço de discussão ou de redacção). Exibe todas as contribuições do fórum público deste artigo e permite-lhe gerir essas contribuições. ',
	'info_liens_syndiques_3' => 'fóruns',
	'info_liens_syndiques_4' => 'são',
	'info_liens_syndiques_5' => 'forum',
	'info_liens_syndiques_6' => 'é',
	'info_liens_syndiques_7' => 'à espera de validação',
	'info_liens_texte' => 'Ligações no texto da mensagem',
	'info_liens_titre' => 'Ligações no título da mensagem',
	'info_mode_fonctionnement_defaut_forum_public' => 'Modo de funcionamento por defeito dos fóruns públicos',
	'info_nb_messages_forum' => '@nb@ mensagens de fórum',
	'info_option_email' => 'Quando um visitante do sítio deixa uma nova mensagem no fórum
 ligado a um artigo, os autores do artigo podem ser informados por e-mail. Deseja activar essa opção ?',
	'info_pas_de_forum' => 'não há fórum',
	'info_question_visiteur_ajout_document_forum' => 'Se pretende autorizar os vistantes a anexar ficheiros (de imagem, som...) às suas mensagens de fórum, indique que extensões de ficheiro são autorizadas (ex: gif, jpg, png, mp3).',
	'info_question_visiteur_ajout_document_forum_format' => 'Se pretende autorizar todos os tipos de documentos considerados seguros por SPIP, use um asterisco. Para não autorizar, deixe vazio.',
	'info_selectionner_message' => 'Seleccionar as mensagens :',
	'interface_formulaire' => 'Formulário da interface',
	'interface_onglets' => 'Interface com guias',
	'item_activer_forum_administrateur' => 'Activar o fórum dos administradores',
	'item_config_forums_prive_global' => 'Activar o fórum dos autores',
	'item_config_forums_prive_objets' => 'Activar estes fóruns',
	'item_desactiver_forum_administrateur' => 'Desactivar o fórum dos administradores',
	'item_non_config_forums_prive_global' => 'Desactivar o fórum dos autores',
	'item_non_config_forums_prive_objets' => 'Desactivar estes fóruns',

	// L
	'label_selectionner' => 'Seleccionar :',
	'lien_reponse_article' => 'Comentário ao artigo',
	'lien_reponse_breve_2' => 'Comentário à notícia',
	'lien_reponse_message' => 'Resposta à mensagem',
	'lien_reponse_rubrique' => 'Comentário à rubrica ',
	'lien_reponse_site_reference' => 'Comentário ao sítio referenciado',
	'lien_vider_selection' => 'Esvaziar a selacção',

	// M
	'messages_aucun' => 'Nenhum',
	'messages_meme_auteur' => 'Todas as mensagens deste autor',
	'messages_meme_email' => 'Todas as mensagens deste e-mail',
	'messages_meme_ip' => 'Todas as mensagens provenientes deste IP',
	'messages_off' => 'Eliminadas',
	'messages_perso' => 'Privadas',
	'messages_privadm' => 'Administradores',
	'messages_prive' => 'Privadas',
	'messages_privoff' => 'Eliminadas',
	'messages_privrac' => 'Geral',
	'messages_prop' => 'Propostas',
	'messages_publie' => 'Publicadas',
	'messages_spam' => 'Spam',
	'messages_tous' => 'Todas',

	// O
	'onglet_messages_internes' => 'Mensagens privadas',
	'onglet_messages_publics' => 'Mensagens públicas',
	'onglet_messages_vide' => 'Mensagens sem texto',

	// R
	'repondre_message' => 'Responder a esta mensagem',

	// S
	'statut_off' => 'Eliminado',
	'statut_original' => 'original',
	'statut_prop' => 'Propostas',
	'statut_publie' => 'Publicadas',
	'statut_spam' => 'Spam',

	// T
	'text_article_propose_publication_forum' => 'Pode comentar este artigo através do fórum abaixo.',
	'texte_en_cours_validation' => 'Os artigos, notícias, fóruns abaixo foram propostos para publicação.',
	'texte_en_cours_validation_forum' => 'Pode comentar livremente nos fóruns anexados.',
	'texte_messages_publics' => 'Meensagens públicas em :',
	'titre_cadre_forum_administrateur' => 'Fórum privado dos administradores',
	'titre_cadre_forum_interne' => 'Fórum interno',
	'titre_config_forums_prive' => 'Fóruns na área privada',
	'titre_forum' => 'Fórum',
	'titre_forum_suivi' => 'Acompanhamento dos fóruns',
	'titre_page_forum_suivi' => 'Acompanhamento dos fóruns',
	'titre_selection_action' => 'Selecção',
	'tout_voir' => 'Visualizar todas as mensagens',

	// V
	'voir_messages_objet' => 'visualizar as mensagens'
);

==> spip_4.2.13+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_pt.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=pt
// ** ne pas modifier le fichier **

return [

	// A
	'aucun_message_forum' => 'Sem mensagens de fórum',

	// B
	'bouton_radio_articles_futurs' => 'aos futuros artigos unicamente (não há acção sobre a base de dados) ',
	'bouton_radio_articles_tous' => 'a todos os artigos sem excepção',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'a todos os artigos, excepto aqueles cujo fórum está desactivado',
	'bouton_radio_enregistrement_obligatoire' => 'Registo obrigatório (os
utilizadores devem ter uma assinatura ao fornecer o seu endereço e-mail antes de
 poderem enviar contribuições).',
	'bouton_radio_moderation_priori' => 'Pré-moderação (as contribuições aparecem publicamente só depois da validação pelos administradores). ',
	'bouton_radio_modere_abonnement' => 'requer assinatura',
	'bouton_radio_modere_posteriori' => 'moderado depois da publicação',
	'bouton_radio_modere_priori' => 'moderado antes da publicação',
	'bouton_radio_publication_immediate' => 'Publicação imediata das mensagens
 (as contribuições afixam-se logo que são enviadas, os administradores podem suprimi-las depois).',

	// D
	'documents_interdits_forum' => 'Documentos proibidos no fórum',

	// E
	'erreur_enregistrement_message' => 'A sua mensagem não pôde ser guardada devido a um problema técnico',
	'extensions_autorisees' => 'Extensões permitidas:',
	'extensions_autorisees_toutes' => 'todas',

	// F
	'form_pet_message_commentaire' => 'Alguma mensagem ou comentário ?',
	'forum' => 'Fórum',
	'forum_acces_refuse' => 'Já não tem acesso a estes fóruns.',
	'forum_attention_dix_caracteres' => '<b>Atenção !</b> a sua mensagem deve conter pelo menos dez carácteres.',
	'forum_attention_message_non_poste' => 'Atenção! Não publicou a sua mensagem!',
	'forum_attention_nb_caracteres_mini' => '<b>Atenção !</b> A sua mensagem deve conter pelo menos @min@ caracteres.',
	'forum_attention_trois_caracteres' => '<b>Atenção !</b> o seu título deve conter pelo menos três carácteres.',
	'forum_attention_trop_caracteres' => '<b>Atenção !</b> A sua mensagem é demasiado longa (@compte@ caracteres) : para poder ser guardada não pode conter mais de @max@ caracteres.',
	'forum_avez_selectionne' => 'Seleccionou :',
	'forum_cliquer_retour' => 'Clique <a href=\'@retour_forum@\'>ici</a> para continuar.',
	'forum_envoyer' => 'Enviar',
	'forum_forum' => 'fórum',
	'forum_info_modere' => 'Este fórum é moderado antes da publicação : a sua contribuição só aparecerá depois de ser validada por um administrador do sítio.',
	'forum_lien_hyper' => '<b>Link hipertexto</b> (opcional)',
	'forum_message' => 'A sua mensagem',
	'forum_message_definitif' => 'Mensagem definitiva: enviar para o sítio',
	'forum_message_trop_long' => 'A sua mensagem é demasiado longa. O tamanho máximo é 20000 carácteres.',
	'forum_ne_repondez_pas' => 'Não responda e este e-mail. Por favor use o fórum, com o endereço seguinte:',
	'forum_page_url' => '(Se a sua mensagem se refere a um artigo publicado na Web, ou a uma página que fornece mais informações, por favor indique a seguir o título da página e o seu endereço URL.)',
	'forum_permalink' => 'Ligação permanente ao comentário',
	'forum_poste_par' => 'Mensagem publicada @parauteur@ a seguir ao seu artigo "@titre@"',
	'forum_poste_par_court' => 'Mensagem publicada @parauteur@.',
	'forum_poste_par_generique' => 'Mensagem publicada @parauteur@ (@objet@ « @titre@ »).',
	'forum_qui_etes_vous' => '<b>Quem é você?</b> (opcional)',
	'forum_saisie_texte_info' => 'este formulário aceita atalhos SPIP <code>[-&gt;url] {{bold}} {itálico} &lt;quote&gt; &lt;code&gt;</code> e o código HTML <code>&lt;q&gt; &lt;del&gt; &lt;ins&gt;</code>. Para criar parágrafos, deixe linhas vazias.',
	'forum_texte' => 'Texto da sua mensagem:',
	'forum_titre' => 'Título:',
	'forum_url' => 'O seu sítio (URL):',
	'forum_valider' => 'Validar a sua escolha',
	'forum_voir_avant' => 'Pré-visualizar',
	'forum_votre_email' => 'O seu endereço e-mail:',
	'forum_votre_nom' => 'O seu nome (pseudónimo):',
	'forum_vous_enregistrer' => 'Para participar
 nesse fórum, deve estar previamente registado. Por favor
  indique a seguir o identificador pessoal que lhe foi
 fornecido. Se não está registado, deve  ',
	'forum_vous_inscrire' => 'inscrever-se.',

	// I
	'icone_bruler_message' => 'Assinalar como Spam',
	'icone_bruler_messages' => 'Assinalar como Spam',
	'icone_legitimer_message' => 'Assinalar como legal',
	'icone_poster_message' => 'Enviar uma mensagem ',
	'icone_suivi_forum' => 'Seguimento do fórum público : @nb_forums@ contribuição(ões)',
	'icone_suivi_forums' => 'Seguir/gerir os fóruns',
	'icone_supprimer_message' => 'Eliminar esta mensagem',
	'icone_supprimer_messages' => 'eliminar estas mensagens',
	'icone_valider_message' => 'Validar esta mensagem',
	'icone_valider_messages' => 'Validar estas mensagens',
	'icone_valider_repondre_message' => 'Validar & Responder a esta mensagem',
	'info_1_message_forum' => '1 mensagem de fórum',
	'info_activer_forum_public' => '<i>Para activar os fóruns públicos, por favor escolha o seu modo
  de moderação por defeito </i>',
	'info_appliquer_choix_moderation' => 'Aplicar esta escolha de moderação :',
	'info_config_forums_prive' => 'Na área privada do sítio pode activar vários tipos de fóruns:',
	'info_config_forums_prive_admin' => 'Um fórum reservado aos administradores do sítio :',
	'info_config_forums_prive_global' => 'Um fórum global, aberto a todos os autores:',
	'info_config_forums_prive_objets' => 'Um fórum sobre cada artigo, notícia, referência, etc.:',
	'info_desactiver_forum_public' => 'Desactivar a utilização dos fóruns
 públicos. Os fóruns públicos poderão ser autorizados caso a caso
 nos artigos ; serão proibidos nas rubricas, notícias, etc.',
	'info_envoi_forum' => 'Envio dos fóruns aos autores dos artigos',
	'info_fonctionnement_forum' => 'Funcionamento do fórum :',
	'info_forcer_previsualisation_court' => 'Forçar pré-visualização',
	'info_forcer_previsualisation_long' => 'Forçar pré-visualização antes de enviar mensagem',
	'info_forums_liees_mot' => 'Mensagens de fórum ligadas a esta palavra-chave',
	'info_gauche_suivi_forum_2' => 'A página <i>gestão dos fóruns </i> é um instrumento de gestão do seu sítio (e não um espaço de discussão ou de redacção). Exibe todas as contribuições do fórum público deste artigo e permite-lhe gerir essas contribuições. ',
	'info_liens_syndiques_3' => 'fóruns',
	'info_liens_syndiques_4' => 'são',
	'info_liens_syndiques_5' => 'forum',
	'info_liens_syndiques_6' => 'é',
	'info_liens_syndiques_7' => 'à espera de validação',
	'info_liens_texte' => 'Ligações no texto da mensagem',
	'info_liens_titre' => 'Ligações no título da mensagem',
	'info_mode_fonctionnement_defaut_forum_public' => 'Modo de funcionamento por defeito dos fóruns públicos',
	'info_nb_messages_forum' => '@nb@ mensagens de fórum',
	'info_option_email' => 'Quando um visitante do sítio deixa uma nova mensagem no fórum
 ligado a um artigo, os autores do artigo podem ser informados por e-mail. Deseja activar essa opção ?',
	'info_pas_de_forum' => 'não há fórum',
	'info_question_visiteur_ajout_document_forum' => 'Se pretende autorizar os vistantes a anexar ficheiros (de imagem, som...) às suas mensagens de fórum, indique que extensões de ficheiro são autorizadas (ex: gif, jpg, png, mp3).',
	'info_question_visiteur_ajout_document_forum_format' => 'Se pretende autorizar todos os tipos de documentos considerados seguros por SPIP, use um asterisco. Para não autorizar, deixe vazio.',
	'info_selectionner_message' => 'Seleccionar as mensagens :',
	'interface_formulaire' => 'Formulário da interface',
	'interface_onglets' => 'Interface com guias',
	'item_activer_forum_administrateur' => 'Activar o fórum dos administradores',
	'item_config_forums_prive_global' => 'Activar o fórum dos autores',
	'item_config_forums_prive_objets' => 'Activar estes fóruns',
	'item_desactiver_forum_administrateur' => 'Desactivar o fórum dos administradores',
	'item_non_config_forums_prive_global' => 'Desactivar o fórum dos autores',
	'item_non_config_forums_prive_objets' => 'Desactivar estes fóruns',

	// L
	'label_selectionner' => 'Seleccionar :',
	'lien_reponse_article' => 'Comentário ao artigo',
	'lien_reponse_breve_2' => 'Comentário à notícia',
	'lien_reponse_message' => 'Resposta à mensagem',
	'lien_reponse_rubrique' => 'Comentário à rubrica ',
	'lien_reponse_site_reference' => 'Comentário ao sítio referenciado',
	'lien_vider_selection' => 'Esvaziar a selacção',

	// M
	'messages_aucun' => 'Nenhum',
	'messages_meme_auteur' => 'Todas as mensagens deste autor',
	'messages_meme_email' => 'Todas as mensagens deste e-mail',
	'messages_meme_ip' => 'Todas as mensagens provenientes deste IP',
	'messages_off' => 'Eliminadas',
	'messages_perso' => 'Privadas',
	'messages_privadm' => 'Administradores',
	'messages_prive' => 'Privadas',
	'messages_privoff' => 'Eliminadas',
	'messages_privrac' => 'Geral',
	'messages_prop' => 'Propostas',
	'messages_publie' => 'Publicadas',
	'messages_spam' => 'Spam',
	'messages_tous' => 'Todas',

	// O
	'onglet_messages_internes' => 'Mensagens privadas',
	'onglet_messages_publics' => 'Mensagens públicas',
	'onglet_messages_vide' => 'Mensagens sem texto',

	// R
	'repondre_message' => 'Responder a esta mensagem',

	// S
	'statut_off' => 'Eliminado',
	'statut_original' => 'original',
	'statut_prop' => 'Propostas',
	'statut_publie' => 'Publicadas',
	'statut_spam' => 'Spam',

	// T
	'text_article_propose_publication_forum' => 'Pode comentar este artigo através do fórum abaixo.',
	'texte_en_cours_validation' => 'Os artigos, notícias, fóruns abaixo foram propostos para publicação.',
	'texte_en_cours_validation_forum' => 'Pode comentar livremente nos fóruns anexados.',
	'texte_messages_publics' => 'Meensagens públicas em :',
	'titre_cadre_forum_administrateur' => 'Fórum privado dos administradores',
	'titre_cadre_forum_interne' => 'Fórum interno',
	'titre_config_forums_prive' => 'Fóruns na área privada',
	'titre_forum' => 'Fórum',
	'titre_forum_suivi' => 'Acompanhamento dos fóruns',
	'titre_page_forum_suivi' => 'Acompanhamento dos fóruns',
	'titre_selection_action' => 'Selecção',
	'tout_voir' => 'Visualizar todas as mensagens',

	// V
	'voir_messages_objet' => 'visualizar as mensagens',
];
